@@ -30,8 +30,8 @@
 class MaximaKeywords
 {
   private:
-    MaximaKeywords();
-    ~MaximaKeywords();
+    MaximaKeywords() = default;
+    ~MaximaKeywords() = default;
   public:
     static MaximaKeywords* instance();
 
@@ -40,7 +40,7 @@ class MaximaKeywords
     const QStringList& variables() const;
 
   private:
-    void loadFromFile();
+    void loadKeywords();
 
   private:
     QStringList m_functions;
