@@ -33,8 +33,6 @@
 #include <QDir>
 #include <QDebug>
 
-#include "settings.h"
-
 static const char description[] =
     I18N_NOOP("KDE Frontend to mathematical applications");
 
@@ -43,8 +41,8 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
 
     // Add our custom plugins path, where we install our plugins, if it isn't default path
-    const QString& path = Settings::pathToCantorPluginsDir().toLocalFile();
-    qDebug() << "Adding additional application library path" << path;
+    const QString& path = QString::fromLocal8Bit(PATH_TO_CANTOR_PLUGINS);
+    qDebug() << "Adding additional application library path for Cantor plugins loading" << path;
     if (!QCoreApplication::libraryPaths().contains(path))
         QCoreApplication::addLibraryPath(path);
 
